==> react-spring-3.0.0.tgz: package/src/Trail.js <==
import React from 'react'
import PropTypes from 'prop-types'
import Animated from './animated/targets/react-dom'
import Spring, { config } from './Spring'

export default class Trail extends React.PureComponent {
    static propTypes = {
        native: PropTypes.bool,
        config: PropTypes.object,
        from: PropTypes.object,
        to: PropTypes.object,
        keys: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.string, PropTypes.number])),
        children: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.func), PropTypes.func]),
        render: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.func), PropTypes.func]),
    }
    static defaultProps = { from: {}, to: {}, native: false, config: config.default }
    render() {
        const { children, render, from, to, native, config, keys, ...extra } = this.props
        const animations = new Set()
        const hook = (index, animation) => {
            animations.add(animation)
            if (index === 0) return undefined
            else return Array.from(animations)[index - 1]
        }
        const props = { ...extra, native, config, from, to }
        return (render || children).map((child, i) => {
            const attachedHook = animation => hook(i, animation)
            return render ? (
                <Spring key={keys[i]} {...props} attach={attachedHook} render={child} children={children} />
            ) : (
                <Spring key={keys[i]} {...props} attach={attachedHook} children={child} />
            )
        })
    }
}

==> react-spring-4.0.2.tgz: package/src/Trail.js <==
import React from 'react'
import PropTypes from 'prop-types'
import Animated from './animated/targets/react-dom'
import Spring, { config } from './Spring'

export default class Trail extends React.PureComponent {
    static propTypes = {
        native: PropTypes.bool,
        config: PropTypes.object,
        from: PropTypes.object,
        to: PropTypes.object,
        keys: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.string, PropTypes.number])),
        children: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.func), PropTypes.func]),
        render: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.func), PropTypes.func]),
    }
    static defaultProps = { from: {}, to: {}, native: false, config: config.default }
    getValues() {
        return this.instance && this.instance.getValues()
    }
    render() {
        const { children, render, from, to, native, config, keys, onRest, ...extra } = this.props
        const animations = new Set()
        const hook = (index, animation) => {
            animations.add(animation)
            if (index === 0) return undefined
            else return Array.from(animations)[index - 1]
        }
        const props = { ...extra, native, config, from, to }
        const target = (render || children)
        return target.map((child, i) => {
            const attachedHook = animation => hook(i, animation)
            return <Spring ref={ref => i === 0 && (this.instance = ref)} onRest={i === 0 ? onRest : null} key={keys[i]} {...props} attach={attachedHook} render={render && child} children={render ? children : child} />
        })
    }
}
